const { execSync } = require('child_process');
const fs = require('fs');
const path = require('path');
const os = require('os');

function ensureDirectory(dir) {
  if (!fs.existsSync(dir)) {
    try {
      fs.mkdirSync(dir, { recursive: true });
      console.log(`创建目录成功: ${dir}`);
    } catch (error) {
      console.error(`创建目录失败 ${dir}:`, error);
      process.exit(1);
    }
  }
}

// 获取全局安装路径
const globalInstallPath = execSync('npm root -g').toString().trim();
console.log('全局安装路径:', globalInstallPath);

// 确保bin目录存在
const binDir = path.join(__dirname, '..', 'bin');
ensureDirectory(binDir);

// 检查系统是否安装了Go
try {
  const goVersion = execSync('go version').toString();
  console.log('Go版本:', goVersion);
} catch (error) {
  console.error('请先安装Go环境：https://golang.org/doc/install');
  process.exit(1);
}

// 编译Go程序
try {
  const platform = os.platform();
  const arch = os.arch();
  const extension = platform === 'win32' ? '.exe' : '';
  const outputPath = path.join(binDir, `cursor-s${extension}`);
  const sourceDir = path.join(__dirname, '..');
  
  console.log('正在编译Go程序...');
  console.log('源代码目录:', sourceDir);
  console.log('输出路径:', outputPath);
  
  // 设置编译环境变量
  const buildEnv = {
    ...process.env,
    CGO_ENABLED: '1',
    GOOS: platform,
    GOARCH: arch,
    GO111MODULE: 'on',
    GOWORK: 'off'  // 禁用工作空间模式
  };

  console.log('编译环境变量:', buildEnv);
  
  // 在源代码目录中执行编译
  execSync('go mod tidy', {
    cwd: sourceDir,
    stdio: 'inherit',
    env: buildEnv
  });
  
  execSync(`go build -v -o ${outputPath} .`, {
    cwd: sourceDir,
    stdio: 'inherit',
    env: buildEnv
  });
  
  // 设置可执行权限
  if (platform !== 'win32') {
    fs.chmodSync(outputPath, 0o755);
    console.log(`设置可执行权限成功: ${outputPath}`);
    
    // 同时设置启动脚本的权限
    const startScript = path.join(binDir, 'cursor-s');
    if (fs.existsSync(startScript)) {
      fs.chmodSync(startScript, 0o755);
      console.log(`设置启动脚本权限成功: ${startScript}`);
    }
  }
  
  // 验证编译结果
  if (fs.existsSync(outputPath)) {
    const stats = fs.statSync(outputPath);
    console.log('编译后的文件大小:', stats.size, '字节');
    console.log('文件权限:', stats.mode.toString(8));
  } else {
    throw new Error('编译成功但找不到输出文件');
  }
  
  console.log('安装完成！');
  console.log('二进制文件路径:', outputPath);
  console.log('请尝试运行: cursor-s');
} catch (error) {
  console.error('编译失败：', error);
  process.exit(1);
} 